@@ -62,6 +62,7 @@ class HashDB(object):
         threadData = getCurrentThreadData()
         try:
             if threadData.hashDBCursor:
+                threadData.hashDBCursor.connection.commit()
                 threadData.hashDBCursor.close()
                 threadData.hashDBCursor.connection.close()
                 threadData.hashDBCursor = None
@@ -115,7 +116,7 @@ class HashDB(object):
                 retVal = None
                 warnMsg = "error occurred while unserializing value for session key '%s'. " % key
                 warnMsg += "If the problem persists please rerun with '--flush-session'"
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
         return retVal
 
@@ -162,7 +163,7 @@ class HashDB(object):
                         if retries == 0:
                             warnMsg = "there has been a problem while writing to "
                             warnMsg += "the session file ('%s')" % getSafeExString(ex)
-                            logger.warn(warnMsg)
+                            logger.warning(warnMsg)
 
                         if retries >= HASHDB_FLUSH_RETRIES:
                             return
@@ -197,6 +198,10 @@ class HashDB(object):
                     threadData.inTransaction = False
                 except sqlite3.OperationalError:
                     pass
+                except sqlite3.ProgrammingError:
+                    self.cursor = None
+                    threadData.inTransaction = False
+                    return
                 else:
                     return
 
